==> mlmmj_1.2.9.orig.tar.gz: mlmmj-1.2.9/contrib/web/php-admin/htdocs/index.php <==
<?php

/* mlmmj/php-admin:
 * Copyright (C) 2004 Christoph Thiel <ct at kki dot org>
 *
 * mlmmj/php-perl:
 * Copyright (C) 2004 Morten K. Poulsen <morten at afdelingp.dk>
 * Copyright (C) 2004 Christian Laursen <christian@pil.dk>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

require("class.FastTemplate.php");
require("../conf/config.php");

$tpl = new FastTemplate($templatedir);

$tpl->define(array("main" => "index.html"));

$lists = "";

$dir = opendir($topdir);
while ($file = readdir($dir)) {
    if (!ereg("^\.",$file))
    {
	$lists .= "<a href=\"edit.php?list=".urlencode($file)."\">".
	    htmlentities($file)."</a><br />\n";
    }
}
closedir($dir); 

$tpl->assign(array("LISTS" => $lists));


$tpl->parse("MAIN","main");
$tpl->FastPrint("MAIN");

?>

==> mlmmj_1.2.17.orig.tar.gz: mlmmj-1.2.17/contrib/web/php-admin/htdocs/index.php <==
<?php

/* mlmmj/php-admin:
 * Copyright (C) 2004 Christoph Thiel <ct at kki dot org>
 *
 * mlmmj/php-perl:
 * Copyright (C) 2004 Morten K. Poulsen <morten at afdelingp.dk>
 * Copyright (C) 2004 Christian Laursen <christian@pil.dk>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

require("class.rFastTemplate.php");
require("../conf/config.php");

$tpl = new rFastTemplate($templatedir);

$tpl->define(array("main" => "index.html"));

$lists = "";

$dir = opendir($topdir);
while ($file = readdir($dir)) {
    if (!ereg("^\.",$file))
    {
	$lists .= "<a href=\"edit.php?list=".urlencode($file)."\">".
	    htmlentities($file)."</a><br />\n";
    }
}
closedir($dir); 

$tpl->assign(array("LISTS" => $lists));


$tpl->parse("MAIN","main");
$tpl->FastPrint("MAIN");

?>
